@@ -13,8 +13,8 @@
 package Messaging::Message::Queue;
 use strict;
 use warnings;
-our $VERSION  = "1.4_1";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "1.6.1";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
@@ -83,10 +83,11 @@ queue (which is the name of the child class), see above
 L<Messaging::Message>,
 L<Messaging::Message::Queue::DQN>,
 L<Messaging::Message::Queue::DQS>,
-L<Messaging::Message::Queue::NULL>.
+L<Messaging::Message::Queue::NULL>,
+L<Messaging::Message::Queue::ZERO>.
 
 =head1 AUTHOR
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2011-2013
+Copyright (C) CERN 2011-2016
