@@ -2,7 +2,7 @@
 #                                                                              #
 # File: Messaging/Message/Queue/NULL.pm                                        #
 #                                                                              #
-# Description: abstraction of a Directory::Queue::Null message queue           #
+# Description: abstraction of a null message queue                             #
 #                                                                              #
 #-##############################################################################
 
@@ -13,22 +13,21 @@
 package Messaging::Message::Queue::NULL;
 use strict;
 use warnings;
-our $VERSION  = "1.4_1";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "1.6.1";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 #
 # inheritance
 #
 
-our @ISA = qw(Messaging::Message::Queue Directory::Queue::Null);
+our @ISA = qw(Messaging::Message::Queue);
 
 #
 # used modules
 #
 
-use Messaging::Message qw(_require);
 use No::Worries::Die qw(dief);
-use Params::Validate qw(validate_with validate_pos :types);
+use Params::Validate qw(validate_with);
 
 #
 # constructor
@@ -37,29 +36,98 @@ use Params::Validate qw(validate_with validate_pos :types);
 sub new : method {
     my($class, %option, $self);
 
-    _require("Directory::Queue::Null");
     $class = shift(@_);
     %option = validate_with(
         params      => \@_,
         spec        => {},
         allow_extra => 0,
     );
-    $self = Directory::Queue::Null->new(%option);
+    $self = {};
     bless($self, $class);
     return($self);
 }
 
+#
+# Directory::Queue methods that can be used
+#
+
+sub first : method {
+    return("");
+}
+
+sub next : method { ## no critic 'ProhibitBuiltinHomonyms'
+    return("");
+}
+
+sub count : method {
+    return(0);
+}
+
+sub purge : method {
+}
+
+sub path : method {
+    return("NULL");
+}
+
+sub id : method {
+    return("NULL");
+}
+
+sub add : method {
+    return("");
+}
+
+#
+# Directory::Queue methods that cannot be used
+#
+
+sub touch : method {
+    dief("unsupported method: touch()");
+}
+
+sub lock : method { ## no critic 'ProhibitBuiltinHomonyms'
+    dief("unsupported method: lock()");
+}
+
+sub unlock : method {
+    dief("unsupported method: unlock()");
+}
+
+sub remove : method {
+    dief("unsupported method: remove()");
+}
+
+sub add_ref : method {
+    dief("unsupported method: add_ref()");
+}
+
+sub add_path : method {
+    dief("unsupported method: add_path()");
+}
+
+sub get : method {
+    dief("unsupported method: get()");
+}
+
+sub get_ref : method {
+    dief("unsupported method: get_ref()");
+}
+
+sub get_path : method {
+    dief("unsupported method: get_path()");
+}
+
+sub copy : method {
+    dief("unsupported method: copy()");
+}
+
 #
 # add a message object to the queue
 #
 
 sub add_message : method {
-    my($self, $msg);
-
-    $self = shift(@_);
-    validate_pos(@_, { isa => "Messaging::Message" });
-    $msg = shift(@_);
-    return($self->add($msg));
+    return("null");
 }
 
 #
@@ -67,14 +135,7 @@ sub add_message : method {
 #
 
 sub get_message : method {
-    my($self, $elt);
-
-    $self = shift(@_);
-    validate_pos(@_, { type => SCALAR });
-    $elt = shift(@_);
-    # the next line should trigger a fatal error as the queue is always empty
-    $self->get($elt);
-    dief("ooops");
+    dief("unsupported method: get_message()");
 }
 
 1;
@@ -83,7 +144,7 @@ __DATA__
 
 =head1 NAME
 
-Messaging::Message::Queue::NULL - abstraction of a Directory::Queue::Null message queue
+Messaging::Message::Queue::NULL - abstraction of a null message queue
 
 =head1 SYNOPSIS
 
@@ -99,15 +160,13 @@ Messaging::Message::Queue::NULL - abstraction of a Directory::Queue::Null messag
 
 =head1 DESCRIPTION
 
-This module provides an abstraction of a message queue. It derives
-from the L<Directory::Queue::Null> module that provides a generic
-"black hole" queue: added messages will disappear immediately so the
-queue will therefore always appear empty.
+This module provides an abstraction of a message queue working a bit like
+C</dev/null>: it can be written to but it always appears empty.
 
 =head1 METHODS
 
-In addition to the methods inherited from L<Directory::Queue::Null>,
-the following methods are available:
+In addition to the standard L<Directory::Queue> methods, the following methods
+are available:
 
 =over
 
@@ -128,7 +187,7 @@ get the message from the given element, this generates an error
 
 =head1 SEE ALSO
 
-L<Directory::Queue::Null>,
+L<Directory::Queue>,
 L<Messaging::Message>,
 L<Messaging::Message::Queue>.
 
@@ -136,4 +195,4 @@ L<Messaging::Message::Queue>.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2011-2013
+Copyright (C) CERN 2011-2016
